@@ -57,15 +57,19 @@ class AthenaClient(TaskQueue):
         Any queries that fail are reset to pending so they will be run a second time
         """
 
-        self._logger.debug("...checking status of query {0} to {1}".format(task.name, task.arguments["output_location"]))
-        status = self.athena.get_query_execution(QueryExecutionId=task.id)["QueryExecution"]["Status"]
+        if task.id is not None:
+            self._logger.debug(
+                "...checking status of query {0} to {1}".format(task.name, task.arguments["output_location"]))
+            status = self.athena.get_query_execution(QueryExecutionId=task.id)["QueryExecution"]["Status"]
 
-        if status["State"] in ("RUNNING", "QUEUED"):
-            task.is_complete = False
-        elif status["State"] == "SUCCEEDED":
-            task.is_complete = True
+            if status["State"] in ("RUNNING", "QUEUED"):
+                task.is_complete = False
+            elif status["State"] == "SUCCEEDED":
+                task.is_complete = True
+            else:
+                task.error = status.get("StateChangeReason", status["State"])
         else:
-            task.error = status.get("StateChangeReason", status["State"])
+            task.is_complete = True
 
     def _trigger_task(self, task):
         """
@@ -137,8 +141,9 @@ class AthenaClient(TaskQueue):
         """
         while self.active_queue:
             task = self.active_queue.pop()
-            self._logger.info("Response while stop_query_execution with following QueryExecutionId {}; {}"
-                        .format(task.id, self.athena.stop_query_execution(QueryExecutionId=task.id)))
+            if task.id is not None:
+                self._logger.info("Response while stop_query_execution with following QueryExecutionId {}; {}"
+                                  .format(task.id, self.athena.stop_query_execution(QueryExecutionId=task.id)))
 
     def stop_and_delete_all_tasks(self):
         """
