@@ -583,19 +583,16 @@ class CachedAthenaQuery(BaseCachedQuery):
 
         self._ac.wait_for_completion()
 
+        compression = 'gzip' if self._gzip else None
+
         for output_file in set(self._results.keys()):
 
             res = self._results.pop(output_file)
-
             actual_file = S3Location(self.cache_path).join(res.id + '.csv')
 
-            # gzip the output
-            if self._gzip:
-                gz_file = output_file
-                with self.dfs.open(actual_file, 'rb') as f_in:
-                    with self.dfs.open(gz_file, 'wb') as f_out:
-                        with gz.open(f_out, 'wb') as gz_out:
-                            shutil.copyfileobj(f_in, gz_out)
+            with self.dfs.open(actual_file, 'rb') as f_in:
+                with self.dfs.open(output_file, 'wb', compression=compression) as f_out:
+                    shutil.copyfileobj(f_in, f_out)
 
             # delete the metadata file
             self.dfs.rm(actual_file)
