@@ -318,6 +318,7 @@ class TestCachedQuery(BaseTest):
             """
             Create a class that mimic's redshift's annoying functionality of producing differently named files
             """
+            _redshift_checks = True
 
             def _execute_query(self,
                                query_file,
@@ -363,6 +364,7 @@ class TestCachedQuery(BaseTest):
             """
             Create a class that mimic's redshift upload multiple files
             """
+            _redshift_checks = True
 
             def _execute_query(self,
                                query_file,
@@ -404,6 +406,7 @@ class TestCachedQuery(BaseTest):
             """
             Create a class that mimic's redshift upload multiple files
             """
+            _redshift_checks = True
 
             def _execute_query(self,
                                query_file,
@@ -452,3 +455,42 @@ class TestCachedQuery(BaseTest):
             q.get_results(sql_file="test_select_bad.sql",
                           output_prefix="test_query",
                           )
+
+    def test_athena_queue(self):
+
+        q = CachedAthenaQuery(params={"aws_region": self.region,
+                                      "athena_db": self.athena_db_name},
+                              cache_path=self.s3_bucket,
+                              sql_paths=[self.sql_path],
+                              sql_archive_path=self.tempdir,
+                              queue_queries=True)
+        self.set_timeouts(q)
+
+        days = [datetime.utcnow() - timedelta(days=1),
+                datetime.utcnow(),
+                datetime.utcnow() + timedelta(days=1)]
+
+        # Clear any previously cached file
+        q.clear_cache(sql_file="athena_test.sql",
+                      output_prefix="athena_test",
+                      params={"day_list": ['{0:%Y-%m-%d}'.format(day) for day in days]})
+
+        r1 = q.get_results(sql_file="athena_test.sql",
+                          output_prefix="athena_test",
+                          params={"day_list": ['{0:%Y-%m-%d}'.format(day) for day in days]})
+
+        r2 = q.get_results(sql_file="athena_test.sql",
+                          output_prefix="athena_test",
+                          params={"day_list": ['{0:%Y-%m-%d}'.format(day) for day in days]})
+
+        r3 = q.get_results(sql_file="athena_test.sql",
+                          output_prefix="athena_test",
+                          params={"day_list": ['{0:%Y-%m-%d}'.format(day) for day in days[:2]]})
+
+        q.wait_for_completion()
+
+        self.assertEqual(r1, r2)
+        dfs = DoggoFileSystem()
+        self.assertTrue(dfs.exists(r1))
+        self.assertTrue(dfs.exists(r2))
+        self.assertTrue(dfs.exists(r3))
\ No newline at end of file
