@@ -3,6 +3,7 @@
 #  This code is licensed under MIT license (see license.txt for details)
 
 import gzip
+import logging
 import multiprocessing
 import os
 import shutil
@@ -14,15 +15,17 @@ import pyarrow as pa
 from pandas.testing import assert_frame_equal
 from s3fs import S3FileSystem
 
-from newtools import CSVDoggo
+from newtools import CSVDoggo, log_to_stdout
 from newtools import PandasDoggo, FileDoggo, S3Location, DoggoFileSystem, DoggoLock, DoggoWait, DynamoDogLock
-from newtools.optional_imports import boto3
+from newtools.optional_imports import boto3, AWSRetry
 from newtools.optional_imports import numpy as np
 from newtools.optional_imports import pandas as pd
 from .base_test import BaseTest
 
 s3_bucket = "newtools-testing"
 
+log_to_stdout("newtools", level=logging.DEBUG)
+
 class TestDoggos(unittest.TestCase):
 
     @classmethod
@@ -109,7 +112,7 @@ class TestDoggos(unittest.TestCase):
         expected_pth = os.path.join(self.base_path, 'csv', 'generic', 'email_test.csv')
         fh = PandasDoggo()
         fh.save(df, pth, index=None)
-        with open(pth) as p, open(expected_pth) as p2:
+        with FileDoggo(pth) as p, FileDoggo(expected_pth) as p2:
             self.assertEqual(p.read().strip(), p2.read().strip())
 
         os.remove(pth)
@@ -428,74 +431,89 @@ class TestDoggoWait(unittest.TestCase):
 
 def check_lock(file):
     test_str = str(random())
-    with DoggoLock(file, wait_period=1, time_out_seconds=2, maximum_age=5):
-        with open(file, "wt") as f:
-            f.write(test_str)
+    with DoggoLock(file, wait_period=0.1, time_out_seconds=20, maximum_age=30):
+        with FileDoggo(file, "wb") as f:
+            f.write(test_str.encode('UTF-8'))
 
-        with open(file, "rt") as f:
-            assert f.read() == test_str
+        with FileDoggo(file, "rb") as f:
+            assert f.read().decode('UTF-8') == test_str
 
         sleep(0.1)
 
+    return True
 
 class BaseLockTest(BaseTest):
     LockClass = None
 
     def test_lock_timeout(self):
         if self.LockClass is not None:
-            file = os.path.join(self.tempdir, 'test_lock_timeout.tmp')
+            file = os.path.join(self.tempdir, f'test_lock_timeout.{random()}tmp')
             with self.LockClass(file, wait_period=1, time_out_seconds=5, maximum_age=20):
+                sleep(0.1)
                 with self.assertRaises(TimeoutError):
                     with self.LockClass(file, wait_period=1, time_out_seconds=2, maximum_age=20):
                         pass
 
     def test_basic(self):
         if self.LockClass is not None:
-            file = os.path.join(self.tempdir, 'test_basic.tmp')
+            file = os.path.join(self.tempdir, f'test_basic.{random()}.tmp')
             check_lock(file)
             check_lock(file)
 
     def test_lock_ages(self):
         if self.LockClass is not None:
-            file = os.path.join(self.tempdir, 'test_lock_ages.tmp')
-            lock_1 = self.LockClass(file, wait_period=1, time_out_seconds=2, maximum_age=5)
-            lock_2 = self.LockClass(file, wait_period=1, time_out_seconds=2, maximum_age=5)
+            file = os.path.join(self.tempdir, f'test_lock_ages.{random()}.tmp')
+            lock_1 = self.LockClass(file, wait_period=1, time_out_seconds=2, maximum_age=10)
+            lock_2 = self.LockClass(file, wait_period=1, time_out_seconds=2, maximum_age=10)
 
             lock_1.acquire()
+            sleep(0.1)
 
             with self.assertRaises(TimeoutError):
                 lock_2.acquire()
 
-            sleep(5)
+            sleep(10)
 
             lock_2.acquire()
 
             lock_1.release()
             lock_2.release()
 
+
+class TestDoggoLockS3(BaseLockTest):
+    tempdir = 's3://newtools-tests-data/locks/'
+    LockClass = DoggoLock
+
+
+class TestDoggoLockLocal(BaseLockTest):
+    LockClass = DoggoLock
+
     def test_lock_multiprocess(self):
         if self.LockClass is not None:
-            file = os.path.join(self.tempdir, 'test_lock_multiprocess.tmp')
-            pool = multiprocessing.Pool()
+            file = os.path.join(self.tempdir, f'test_lock_multiprocess.{random()}.tmp')
 
-            for _ in range(0, 10):
-                pool.apply_async(check_lock,
-                                 (file,))
+            processes=list()
+            pool = multiprocessing.Pool()
+            for _ in range(0, min(10, multiprocessing.cpu_count() -1)):
+                processes.append(
+                    pool.apply_async(check_lock,
+                                     (file,))
+                )
 
             pool.close()
             pool.join()
 
-
-class TestDoggoLock(BaseLockTest):
-    tempdir = 's3://newtools-tests-data/locks/'
-    LockClass = DoggoLock
+            self.assertTrue(all([x.get() for x in processes]))
 
 
 class TestDynamoDogLock(BaseLockTest):
     LockClass = DynamoDogLock
 
     def test_lock_create_dynamo_table(self):
-        boto3.resource("dynamodb", region_name="us-east-1").Table("newtools.dynamo.doggo.lock").delete()
+        boto3.resource("dynamodb", region_name="us-east-1").Table(DynamoDogLock._table_name).delete()
+        waiter = boto3.client("dynamodb", region_name="us-east-1").get_waiter('table_not_exists')
+        waiter.wait(TableName=DynamoDogLock._table_name,
+                    WaiterConfig={'Delay': 2, 'MaxAttempts': 120})
 
         file = os.path.join(self.tempdir, 'test_lock_ages.tmp')
         with self.LockClass(file, wait_period=1, time_out_seconds=2, maximum_age=5):
